"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fromTemporaryCredentials = void 0;
var fromTemporaryCredentials_base_1 = require("./fromTemporaryCredentials.base");
Object.defineProperty(exports, "fromTemporaryCredentials", { enumerable: true, get: function () { return fromTemporaryCredentials_base_1.fromTemporaryCredentials; } });
