import { FromProcessInit } from "@aws-sdk/credential-provider-process";
import { AwsCredentialIdentityProvider } from "@smithy/types";
export declare const fromProcess: (
  init?: FromProcessInit
) => AwsCredentialIdentityProvider;
