import { FromIniInit } from "@aws-sdk/credential-provider-ini";
import { RuntimeConfigAwsCredentialIdentityProvider } from "@aws-sdk/types";
export declare const fromIni: (
  init?: FromIniInit
) => RuntimeConfigAwsCredentialIdentityProvider;
