import { fromContainerMetadata as _fromContainerMetadata, } from "@smithy/credential-provider-imds";
export const fromContainerMetadata = (init) => {
    init?.logger?.debug("@smithy/credential-provider-imds", "fromContainerMetadata");
    return _fromContainerMetadata(init);
};
