import { fromCognitoIdentity as _fromCognitoIdentity, } from "@aws-sdk/credential-provider-cognito-identity";
export const fromCognitoIdentity = (options) => _fromCognitoIdentity({
    ...options,
});
