export * from "./fromCognitoIdentity";
export * from "./fromCognitoIdentityPool";
export { fromHttp } from "@aws-sdk/credential-provider-http";
export {
  FromHttpOptions,
  HttpProviderCredentials,
} from "@aws-sdk/credential-provider-http";
export * from "./fromTemporaryCredentials.browser";
export * from "./fromWebToken";
