import { RuntimeConfigAwsCredentialIdentityProvider } from "@aws-sdk/types";
import { FromTemporaryCredentialsOptions } from "./fromTemporaryCredentials.base";
export { FromTemporaryCredentialsOptions };
export declare const fromTemporaryCredentials: (
  options: FromTemporaryCredentialsOptions
) => RuntimeConfigAwsCredentialIdentityProvider;
