import { FromSSOInit } from "@aws-sdk/credential-provider-sso";
import { AwsCredentialIdentityProvider } from "@smithy/types";
export declare const fromSSO: (
  init?: FromSSOInit
) => AwsCredentialIdentityProvider;
