import { FromTokenFileInit } from "@aws-sdk/credential-provider-web-identity";
import { AwsCredentialIdentityProvider } from "@smithy/types";
export declare const fromTokenFile: (
  init?: FromTokenFileInit
) => AwsCredentialIdentityProvider;
